==> hk2-api-2.2.0-b10-sources.jar: org/glassfish/hk2/api/ProxyForSameScope.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2.api;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * This annotation is used when automatically analyzing a class or a 
 * {link {@link Factory#provide()} method to indicate that the descriptor
 * either should or should use a proxy when being injected into a service
 * from the same scope.  This annotation is only used
 * for automatic class analysis, and the value in a descriptor will not be
 * checked against this annotation at run time.
 * <p>
 * Note that this annotation is NOT inherited, and hence must be on
 * the analyzed class itself, and not superclasses or interfaces
 * of the analyzed class
 * <p>
 * @see {@link Proxiable}, {@link Unproxiable}, {@link UseProxy}
 * 
 * @author jwells
 */
@Documented
@Retention(RUNTIME)
@Target( { METHOD, TYPE })
public @interface ProxyForSameScope {
    /**
     * If this returns true then the isProxyForSameScope will be set to true, but
     * if this returns false then the isProxyForSameScope will be set to false
     * 
     * @return The value that the isProxyForSameScope field of the descriptor should take
     */
    public boolean value() default true;

}

==> hk2-api-2.4.0-b10-sources.jar: org/glassfish/hk2/api/ProxyForSameScope.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2.api;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.TYPE;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * This annotation is used when automatically analyzing a class or a 
 * {link {@link Factory#provide()} method to indicate that the descriptor
 * either should or should use a proxy when being injected into a service
 * from the same scope.  This annotation is only used
 * for automatic class analysis, and the value in a descriptor will not be
 * checked against this annotation at run time.
 * <p>
 * Note that this annotation is NOT inherited, and hence must be on
 * the analyzed class itself, and not superclasses or interfaces
 * of the analyzed class
 * <p>
 * @see Proxiable Unproxiable UseProxy
 * 
 * @author jwells
 */
@Documented
@Retention(RUNTIME)
@Target( { METHOD, TYPE })
public @interface ProxyForSameScope {
    /**
     * If this returns true then the isProxyForSameScope will be set to true, but
     * if this returns false then the isProxyForSameScope will be set to false
     * 
     * @return The value that the isProxyForSameScope field of the descriptor should take
     */
    public boolean value() default true;

}
